# emojigg
An async API wrapper for [emoji.gg](https://emoji.gg/). 

Useful for Discord Bots using [discord.py](https://github.com/Rapptz/discord.py), or for any project you're working on.

# Note
This wrapper is still under heavy development -> anything is due to change.

# Installing
**Recommended Python 3.5.3 or higher**

To install the library you can do the following
```python
# Linux / MacOS
python -m pip install emojigg

# Windows
py -m pip install emojigg
```


# Links
Docs (temp): [Wiki](https://github.com/NextChai/Emojigg/wiki)

Pypi: [pypi](https://pypi.org/project/emojigg/)
